==> eea.rdfrepository-0.3.zip: eea.rdfrepository-0.3/src/eea/rdfrepository/utils.py <==
from eea.rdfrepository.interfaces import IRDFPortletInfo
from eea.rdfrepository.interfaces import IRDFPortletDataCollector
from zope.component import getMultiAdapter

def getPublishedByAttr(item):
    return item.published_unparsed

def getPublishedByGet(item):
    return item.get('published')

def getFeedItemsWithoutDuplicates(items, sort=False, published_attr=False):
    # store the items in a hash, if two items has the same url/link
    # only the one with latest published date will be stored in the hash

    links = {}

    # if the item is a IFeedItem then we can use .get('published') to get
    # the published date, otherwise we assume there's a published_unparsed attr
    if published_attr:
        published_func = getPublishedByAttr
    else:
        published_func = getPublishedByGet

    for item in items:
        link = item.url
        item_published = published_func(item)

        if link not in links:
            links[link] = item
        elif item_published > published_func(links[link]):
            links[link] = item

    items = links.values()
    if sort:
        items.sort(key=lambda x:published_func(x), reverse=True)

    return items

def getRdfPortletData(context, max_items=3):
    feeds = IRDFPortletDataCollector(context).feeds
    # only save the relevant feed items so it doesn't do
    # unnecessary processing
    if feeds is not None:
        for feed in feeds:
            feed.items = feed.items[:max_items]
        return [getMultiAdapter((context, feed), IRDFPortletInfo) for feed in feeds] #pyflakes, #pylint: disable-msg = W0631,
    return []

==> eea.rdfrepository-4.2.zip: eea.rdfrepository-4.2/src/eea/rdfrepository/utils.py <==
""" Utils
"""
from eea.rdfrepository.interfaces import IRDFPortletInfo
from eea.rdfrepository.interfaces import IRDFPortletDataCollector
from zope.component import getMultiAdapter

def getPublishedByAttr(item):
    """ Get Published By Attr
    """
    return item.published_unparsed

def getPublishedByGet(item):
    """ Get Published By Get
    """
    return item.get('published')

def getFeedItemsWithoutDuplicates(items, sort=False, published_attr=False):
    """ Get Feed Items Without Duplicates
    """
    # store the items in a hash, if two items has the same url/link
    # only the one with latest published date will be stored in the hash

    links = {}

    # if the item is a IFeedItem then we can use .get('published') to get
    # the published date, otherwise we assume there's a published_unparsed attr
    if published_attr:
        published_func = getPublishedByAttr
    else:
        published_func = getPublishedByGet

    for item in items:
        link = item.url
        item_published = published_func(item)

        if link not in links:
            links[link] = item
        elif item_published > published_func(links[link]):
            links[link] = item

    items = links.values()
    if sort:
        items.sort(key=lambda x:published_func(x), reverse=True)

    return items

def getRdfPortletData(context, max_items=3):
    """ Get Rdf Portlet Data
    """
    feeds = IRDFPortletDataCollector(context).feeds
    # Only save the relevant feed items so it doesn't do
    # unnecessary processing
    if feeds:
        for feed in feeds:
            feed.items = feed.items[:max_items]
        return [getMultiAdapter((context, feed_max), IRDFPortletInfo)
                                                       for feed_max in feeds]
    return []
